aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorRoger Dingledine <arma@torproject.org>2010-10-01 14:12:11 -0400
committerRoger Dingledine <arma@torproject.org>2010-10-01 14:12:11 -0400
commit165aaf560a7249a388e916659d55ec6fa1d2fd24 (patch)
treeec2a1d2abfe60a0b355cc414a330c3c8609bc237 /src
parenta00d48b4c33417b600959874812e87d1c6045223 (diff)
parent734ba2f93728af85d1a7d1e0ef7d7c4ae82783a5 (diff)
downloadtor-165aaf560a7249a388e916659d55ec6fa1d2fd24.tar.gz
tor-165aaf560a7249a388e916659d55ec6fa1d2fd24.zip
Merge branch 'maint-0.2.2'
Diffstat (limited to 'src')
-rw-r--r--src/or/router.c7
1 files changed, 6 insertions, 1 deletions
diff --git a/src/or/router.c b/src/or/router.c
index 621cbaace5..8b3a1849ac 100644
--- a/src/or/router.c
+++ b/src/or/router.c
@@ -1257,6 +1257,8 @@ static int router_guess_address_from_dir_headers(uint32_t *guess);
int
router_pick_published_address(or_options_t *options, uint32_t *addr)
{
+ char buf[INET_NTOA_BUF_LEN];
+ struct in_addr a;
if (resolve_my_address(LOG_INFO, options, addr, NULL) < 0) {
log_info(LD_CONFIG, "Could not determine our address locally. "
"Checking if directory headers provide any hints.");
@@ -1266,6 +1268,9 @@ router_pick_published_address(or_options_t *options, uint32_t *addr)
return -1;
}
}
+ a.s_addr = htonl(*addr);
+ tor_inet_ntoa(&a, buf, sizeof(buf));
+ log_info(LD_CONFIG,"Success: chose address '%s'.", buf);
return 0;
}
@@ -1289,7 +1294,7 @@ router_rebuild_descriptor(int force)
if (router_pick_published_address(options, &addr) < 0) {
/* Stop trying to rebuild our descriptor every second. We'll
* learn that it's time to try again when server_has_changed_ip()
* marks it dirty. */
desc_clean_since = time(NULL);
return -1;
@@ -1289,7 +1294,7 @@ router_rebuild_descriptor(int force)
if (router_pick_published_address(options, &addr) < 0) {
/* Stop trying to rebuild our descriptor every second. We'll
- * learn that it's time to try again when server_has_changed_ip()
+ * learn that it's time to try again when ip_address_changed()
* marks it dirty. */
desc_clean_since = time(NULL);